#
# spec file for package python-pypandoc
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define base_name pypandoc
%{?sle15_python_module_pythons}
Name:           python-pypandoc
Version:        1.15
Release:        1.1
Summary:        Thin wrapper for pandoc
License:        MIT
URL:            https://github.com/JessicaTegner/pypandoc
Source:         https://github.com/JessicaTegner/pypandoc/archive/refs/tags/v%{version}.tar.gz#/pypandoc-%{version}.tar.gz
BuildRequires:  %{python_module pandocfilters}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  pandoc
BuildRequires:  python-rpm-macros
BuildRequires:  texlive-latex-bin
BuildRequires:  texlive-xcolor
BuildRequires:  tex(amsmath.sty)
BuildRequires:  tex(bookmark.sty)
Requires:       pandoc
Suggests:       ghc-citeproc
ExcludeArch:    %{ix86}
BuildArch:      noarch
%python_subpackages

%description
pypandoc provides a thin wrapper for pandoc, a universal document converter.

%prep
%autosetup -p1 -n pypandoc-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# 'test_basic_conversion_from_http_url' needs network
# 'test_conversion_with_data_files' => https://github.com/JessicaTegner/pypandoc/issues/278
%pytest tests.py -k 'not test_basic_conversion_from_http_url and not test_conversion_with_data_files and not test_basic_conversion_from_file_pattern_pathlib_glob'

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/pypandoc
%{python_sitelib}/pypandoc-%{version}.dist-info

%changelog
* Thu Feb 13 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.15
  * Added support for python 3.13 - Removed ubber bound (#379)
  * Added parameter to control if files are sorted before being
    passed to pandoc (#378)
  * Dropped CI support for older python and pypy versions (#387)
  * Fix convert_file for Python 3.13 (#384)
  * allow non-latex intermediaries for pdf generation (#381)
- Drop remove-py313-upper-bound.patch, merged upstream
* Wed Nov 20 2024 Dirk Müller <dmueller@suse.com>
- add remove-py313-upper-bound.patch: fix build with python 3.13
- cleanup url/source links
* Fri Oct 25 2024 Earl Sampson <esampson@suse.com>
- enable sle15_python_module_pythons
* Fri Oct 18 2024 Dirk Müller <dmueller@suse.com>
- update to 1.14:
  * Fix regex escape
  * add project urls to setup files
  * Fix invalid escape sequence in regex
* Wed Apr  3 2024 Steve Kowalik <steven.kowalik@suse.com>
- Add missing tex style amsmath.sty to BuildRequires.
* Thu Mar 14 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.13:
  * Change when we do source file verification
- Drop tests.py file, it is shipped in the source tarball.
- Switch to pyproject macros.
* Wed May 24 2023 Scott Bradnick <scott.bradnick@suse.com>
- Updating to upstream version 1.11 (as previous 1.6.4 fails)
  * tests.py was also updated and needed another item excluded to
    possibly account for how pandoc is built.
- Converting to noarch (per rpmlint).
- Adding pandocfilters module to BuildRequires
* Sun Jul 17 2022 John Vandenberg <jayvdb@gmail.com>
- Add build dependency texlive-xcolor
* Mon Dec 20 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Exclude build for %%ix86: pandoc (entire haskell stack) is not
  available on i586.
- As a result, do not mark package noarch: due to the missing
  pandoc dependency, it is uninstallable on i586.
* Sat Dec  4 2021 John Vandenberg <jayvdb@gmail.com>
- Update to v1.6.4
- Remove no longer needed fix-test.patch
- Add tests.py from upstream master to workaround failures
* Sun Dec 27 2020 Jason Craig <os-dev@jacraig.com>
- Add fix-test.patch to fix test: according to Pandoc documentation,
  ATX-style headings are the default. See
  https://pandoc.org/MANUAL#option--markdown-headings
* Sun Nov 22 2020 John Vandenberg <jayvdb@gmail.com>
- Replace ghc-pandoc-citeproc, removed as obsolete, with ghc-citeproc
* Thu Jul 23 2020 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
- Update to v1.5
* Wed Aug 16 2017 daniel.molkentin@suse.com
- Add fdupes
* Tue Aug 15 2017 daniel.molkentin@suse.com
- Update to 1.4
- Convert to single spec
- Ran spec cleaner
* Tue Jan 24 2017 termim@gmail.com
- Initial check in version 1.3.3
